==> icon_forest-1.0.2.tar.gz: lib/flat_icons_arrows.dart <==
import 'package:flutter/material.dart';

class _FlatIconsFlutterArrows extends IconData {
  const _FlatIconsFlutterArrows(int codePoint)
      : super(codePoint,
            fontFamily: 'flat_icons_arrows', fontPackage: 'icon_forest');
}

class FlatIconsArrows {
  static const IconData back_a = _FlatIconsFlutterArrows(0xf100);
  static const IconData con_back_1_a = _FlatIconsFlutterArrows(0xf101);
  static const IconData con_backspace_a = _FlatIconsFlutterArrows(0xf102);
  static const IconData con_backward_a = _FlatIconsFlutterArrows(0xf103);
  static const IconData con_center_align_a = _FlatIconsFlutterArrows(0xf104);
  static const IconData con_circuit_a = _FlatIconsFlutterArrows(0xf105);
  static const IconData con_circuit_1_a = _FlatIconsFlutterArrows(0xf106);
  static const IconData con_circuit_10_a = _FlatIconsFlutterArrows(0xf107);
  static const IconData con_circuit_2_a = _FlatIconsFlutterArrows(0xf108);
  static const IconData con_circuit_3_a = _FlatIconsFlutterArrows(0xf109);
  static const IconData con_circuit_4_a = _FlatIconsFlutterArrows(0xf10a);
  static const IconData con_circuit_5_a = _FlatIconsFlutterArrows(0xf10b);
  static const IconData con_circuit_6_a = _FlatIconsFlutterArrows(0xf10c);
  static const IconData con_circuit_7_a = _FlatIconsFlutterArrows(0xf10d);
  static const IconData con_circuit_8_a = _FlatIconsFlutterArrows(0xf10e);
  static const IconData con_circuit_9_a = _FlatIconsFlutterArrows(0xf10f);
  static const IconData con_compress_a = _FlatIconsFlutterArrows(0xf110);
  static const IconData con_curved_a = _FlatIconsFlutterArrows(0xf111);
  static const IconData con_curved_arrow_a = _FlatIconsFlutterArrows(0xf112);
  static const IconData con_curved_arrow_1_a = _FlatIconsFlutterArrows(0xf113);
  static const IconData con_curved_arrow_2_a = _FlatIconsFlutterArrows(0xf114);
  static const IconData con_curved_arrow_3_a = _FlatIconsFlutterArrows(0xf115);
  static const IconData con_curved_arrow_4_a = _FlatIconsFlutterArrows(0xf116);
  static const IconData con_curved_arrow_5_a = _FlatIconsFlutterArrows(0xf117);
  static const IconData con_curved_arrow_6_a = _FlatIconsFlutterArrows(0xf118);
  static const IconData con_curved_arrow_7_a = _FlatIconsFlutterArrows(0xf119);
  static const IconData con_curved_arrow_8_a = _FlatIconsFlutterArrows(0xf11a);
  static const IconData con_cycle_a = _FlatIconsFlutterArrows(0xf11b);
  static const IconData con_diagonal_a = _FlatIconsFlutterArrows(0xf11c);
  static const IconData con_diagonal_1_a = _FlatIconsFlutterArrows(0xf11d);
  static const IconData con_diagonal_2_a = _FlatIconsFlutterArrows(0xf11e);
  static const IconData con_diagonal_3_a = _FlatIconsFlutterArrows(0xf11f);
  static const IconData con_diagonal_4_a = _FlatIconsFlutterArrows(0xf120);
  static const IconData con_diagonal_5_a = _FlatIconsFlutterArrows(0xf121);
  static const IconData con_diagonal_6_a = _FlatIconsFlutterArrows(0xf122);
  static const IconData con_diagonal_7_a = _FlatIconsFlutterArrows(0xf123);
  static const IconData con_diagonal_8_a = _FlatIconsFlutterArrows(0xf124);
  static const IconData con_diagonal_9_a = _FlatIconsFlutterArrows(0xf125);
  static const IconData con_diagonal_arrow_a = _FlatIconsFlutterArrows(0xf126);
  static const IconData con_diagonal_arrow_1_a =
      _FlatIconsFlutterArrows(0xf127);
  static const IconData con_divide_a = _FlatIconsFlutterArrows(0xf128);
  static const IconData con_down_arrow_a = _FlatIconsFlutterArrows(0xf129);
  static const IconData con_down_arrow_1_a = _FlatIconsFlutterArrows(0xf12a);
  static const IconData con_down_arrow_2_a = _FlatIconsFlutterArrows(0xf12b);
  static const IconData con_down_arrow_3_a = _FlatIconsFlutterArrows(0xf12c);
  static const IconData con_down_arrow_4_a = _FlatIconsFlutterArrows(0xf12d);
  static const IconData con_down_arrow_5_a = _FlatIconsFlutterArrows(0xf12e);
  static const IconData con_download_a = _FlatIconsFlutterArrows(0xf12f);
  static const IconData con_download_1_a = _FlatIconsFlutterArrows(0xf130);
  static const IconData con_download_2_a = _FlatIconsFlutterArrows(0xf131);
  static const IconData con_download_3_a = _FlatIconsFlutterArrows(0xf132);
  static const IconData con_download_4_a = _FlatIconsFlutterArrows(0xf133);
  static const IconData con_download_5_a = _FlatIconsFlutterArrows(0xf134);
  static const IconData con_drag_a = _FlatIconsFlutterArrows(0xf135);
  static const IconData con_drag_1_a = _FlatIconsFlutterArrows(0xf136);
  static const IconData con_drag_10_a = _FlatIconsFlutterArrows(0xf137);
  static const IconData con_drag_11_a = _FlatIconsFlutterArrows(0xf138);
  static const IconData con_drag_2_a = _FlatIconsFlutterArrows(0xf139);
  static const IconData con_drag_3_a = _FlatIconsFlutterArrows(0xf13a);
  static const IconData con_drag_4_a = _FlatIconsFlutterArrows(0xf13b);
  static const IconData con_drag_5_a = _FlatIconsFlutterArrows(0xf13c);
  static const IconData con_drag_6_a = _FlatIconsFlutterArrows(0xf13d);
  static const IconData con_drag_7_a = _FlatIconsFlutterArrows(0xf13e);
  static const IconData con_drag_8_a = _FlatIconsFlutterArrows(0xf13f);
  static const IconData con_drag_9_a = _FlatIconsFlutterArrows(0xf140);
  static const IconData con_expand_a = _FlatIconsFlutterArrows(0xf141);
  static const IconData con_expand_1_a = _FlatIconsFlutterArrows(0xf142);
  static const IconData con_expand_2_a = _FlatIconsFlutterArrows(0xf143);
  static const IconData con_expand_3_a = _FlatIconsFlutterArrows(0xf144);
  static const IconData con_expand_4_a = _FlatIconsFlutterArrows(0xf145);
  static const IconData con_expand_5_a = _FlatIconsFlutterArrows(0xf146);
  static const IconData con_expand_6_a = _FlatIconsFlutterArrows(0xf147);
  static const IconData con_expand_7_a = _FlatIconsFlutterArrows(0xf148);
  static const IconData con_fast_forward_a = _FlatIconsFlutterArrows(0xf149);
  static const IconData con_focus_a = _FlatIconsFlutterArrows(0xf14a);
  static const IconData con_focus_1_a = _FlatIconsFlutterArrows(0xf14b);
  static const IconData con_forward_a = _FlatIconsFlutterArrows(0xf14c);
  static const IconData con_forward_1_a = _FlatIconsFlutterArrows(0xf14d);
  static const IconData con_horizontal_arrows_a =
      _FlatIconsFlutterArrows(0xf14e);
  static const IconData con_import_a = _FlatIconsFlutterArrows(0xf150);
  static const IconData con_left_arrow_a = _FlatIconsFlutterArrows(0xf151);
  static const IconData con_left_arrow_1_a = _FlatIconsFlutterArrows(0xf152);
  static const IconData con_left_arrow_2_a = _FlatIconsFlutterArrows(0xf153);
  static const IconData con_left_arrow_3_a = _FlatIconsFlutterArrows(0xf154);
  static const IconData con_left_arrow_4_a = _FlatIconsFlutterArrows(0xf155);
  static const IconData con_left_arrow_5_a = _FlatIconsFlutterArrows(0xf156);
  static const IconData con_left_arrow_6_a = _FlatIconsFlutterArrows(0xf157);
  static const IconData con_minimize_a = _FlatIconsFlutterArrows(0xf158);
  static const IconData con_minimize_1_a = _FlatIconsFlutterArrows(0xf159);
  static const IconData con_minimize_2_a = _FlatIconsFlutterArrows(0xf15a);
  static const IconData con_move_a = _FlatIconsFlutterArrows(0xf15b);
  static const IconData con_move_1_a = _FlatIconsFlutterArrows(0xf15c);
  static const IconData con_move_2_a = _FlatIconsFlutterArrows(0xf15d);
  static const IconData con_move_3_a = _FlatIconsFlutterArrows(0xf15e);
  static const IconData con_multiply_a = _FlatIconsFlutterArrows(0xf15f);
  static const IconData con_multiply_1_a = _FlatIconsFlutterArrows(0xf160);
  static const IconData con_multiply_2_a = _FlatIconsFlutterArrows(0xf161);
  static const IconData con_multiply_3_a = _FlatIconsFlutterArrows(0xf162);
  static const IconData con_multiply_4_a = _FlatIconsFlutterArrows(0xf163);
  static const IconData con_multiply_5_a = _FlatIconsFlutterArrows(0xf164);
  static const IconData con_multiply_6_a = _FlatIconsFlutterArrows(0xf165);
  static const IconData con_multiply_7_a = _FlatIconsFlutterArrows(0xf166);
  static const IconData con_multiply_8_a = _FlatIconsFlutterArrows(0xf167);
  static const IconData con_multiply_9_a = _FlatIconsFlutterArrows(0xf168);
  static const IconData con_next_a = _FlatIconsFlutterArrows(0xf169);
  static const IconData con_next_1_a = _FlatIconsFlutterArrows(0xf16a);
  static const IconData con_orbit_a = _FlatIconsFlutterArrows(0xf16b);
  static const IconData con_play_button_a = _FlatIconsFlutterArrows(0xf16c);
  static const IconData con_random_a = _FlatIconsFlutterArrows(0xf16d);
  static const IconData con_refresh_a = _FlatIconsFlutterArrows(0xf16e);
  static const IconData con_repeat_a = _FlatIconsFlutterArrows(0xf16f);
  static const IconData con_repeat_1_a = _FlatIconsFlutterArrows(0xf170);
  static const IconData con_resize_a = _FlatIconsFlutterArrows(0xf171);
  static const IconData con_return_a = _FlatIconsFlutterArrows(0xf172);
  static const IconData con_return_1_a = _FlatIconsFlutterArrows(0xf173);
  static const IconData con_return_2_a = _FlatIconsFlutterArrows(0xf174);
  static const IconData con_return_3_a = _FlatIconsFlutterArrows(0xf175);
  static const IconData con_rewind_a = _FlatIconsFlutterArrows(0xf176);
  static const IconData con_right_a = _FlatIconsFlutterArrows(0xf177);
  static const IconData con_right_arrow_a = _FlatIconsFlutterArrows(0xf178);
  static const IconData con_right_arrow_1_a = _FlatIconsFlutterArrows(0xf179);
  static const IconData con_right_arrow_2_a = _FlatIconsFlutterArrows(0xf17a);
  static const IconData con_right_arrow_3_a = _FlatIconsFlutterArrows(0xf17b);
  static const IconData con_right_arrow_4_a = _FlatIconsFlutterArrows(0xf17c);
  static const IconData con_right_arrow_5_a = _FlatIconsFlutterArrows(0xf17d);
  static const IconData con_right_arrow_6_a = _FlatIconsFlutterArrows(0xf17e);
  static const IconData con_roundabout_a = _FlatIconsFlutterArrows(0xf17f);
  static const IconData con_roundabout_1_a = _FlatIconsFlutterArrows(0xf180);
  static const IconData con_shuffle_a = _FlatIconsFlutterArrows(0xf181);
  static const IconData con_shuffle_1_a = _FlatIconsFlutterArrows(0xf182);
  static const IconData con_shuffle_2_a = _FlatIconsFlutterArrows(0xf183);
  static const IconData con_sort_a = _FlatIconsFlutterArrows(0xf184);
  static const IconData con_sort_1_a = _FlatIconsFlutterArrows(0xf185);
  static const IconData con_spin_a = _FlatIconsFlutterArrows(0xf186);
  static const IconData con_spin_1_a = _FlatIconsFlutterArrows(0xf187);
  static const IconData con_spin_2_a = _FlatIconsFlutterArrows(0xf188);
  static const IconData con_spin_3_a = _FlatIconsFlutterArrows(0xf189);
  static const IconData con_square_a = _FlatIconsFlutterArrows(0xf18a);
  static const IconData con_transfer_a = _FlatIconsFlutterArrows(0xf18b);
  static const IconData con_transfer_1_a = _FlatIconsFlutterArrows(0xf18c);
  static const IconData con_transfer_2_a = _FlatIconsFlutterArrows(0xf18d);
  static const IconData con_transfer_3_a = _FlatIconsFlutterArrows(0xf18e);
  static const IconData con_transfer_4_a = _FlatIconsFlutterArrows(0xf18f);
  static const IconData con_transfer_5_a = _FlatIconsFlutterArrows(0xf190);
  static const IconData con_transfer_6_a = _FlatIconsFlutterArrows(0xf191);
  static const IconData con_transfer_7_a = _FlatIconsFlutterArrows(0xf192);
  static const IconData con_transfer_8_a = _FlatIconsFlutterArrows(0xf193);
  static const IconData con_up_arrow_a = _FlatIconsFlutterArrows(0xf194);
  static const IconData con_up_arrow_1_a = _FlatIconsFlutterArrows(0xf195);
  static const IconData con_up_arrow_2_a = _FlatIconsFlutterArrows(0xf196);
  static const IconData con_up_arrow_3_a = _FlatIconsFlutterArrows(0xf197);
  static const IconData con_up_arrow_4_a = _FlatIconsFlutterArrows(0xf198);
  static const IconData con_up_arrow_5_a = _FlatIconsFlutterArrows(0xf199);
  static const IconData con_up_arrow_6_a = _FlatIconsFlutterArrows(0xf19a);
  static const IconData con_up_arrow_7_a = _FlatIconsFlutterArrows(0xf19b);
  static const IconData con_up_arrow_8_a = _FlatIconsFlutterArrows(0xf19c);
  static const IconData con_upload_a = _FlatIconsFlutterArrows(0xf19d);
  static const IconData con_upload_1_a = _FlatIconsFlutterArrows(0xf19e);
  static const IconData con_upward_a = _FlatIconsFlutterArrows(0xf19f);
}

==> icon_forest-1.0.9.tar.gz: lib/flat_icons_arrows.dart <==
import 'package:flutter/material.dart';

/// flat_icons_flutter (Arrow) icon pack (159 icons)
class _FlatIconsFlutterArrows extends IconData {
  const _FlatIconsFlutterArrows(int codePoint) : super(codePoint, fontFamily: 'flat_icons_arrows', fontPackage: 'icon_forest');
}

/// constants link to font code point
class FlatIconsArrows {
  static const IconData back_a = _FlatIconsFlutterArrows(0xf100);
  static const IconData con_back_1_a = _FlatIconsFlutterArrows(0xf101);
  static const IconData con_backspace_a = _FlatIconsFlutterArrows(0xf102);
  static const IconData con_backward_a = _FlatIconsFlutterArrows(0xf103);
  static const IconData con_center_align_a = _FlatIconsFlutterArrows(0xf104);
  static const IconData con_circuit_a = _FlatIconsFlutterArrows(0xf105);
  static const IconData con_circuit_1_a = _FlatIconsFlutterArrows(0xf106);
  static const IconData con_circuit_10_a = _FlatIconsFlutterArrows(0xf107);
  static const IconData con_circuit_2_a = _FlatIconsFlutterArrows(0xf108);
  static const IconData con_circuit_3_a = _FlatIconsFlutterArrows(0xf109);
  static const IconData con_circuit_4_a = _FlatIconsFlutterArrows(0xf10a);
  static const IconData con_circuit_5_a = _FlatIconsFlutterArrows(0xf10b);
  static const IconData con_circuit_6_a = _FlatIconsFlutterArrows(0xf10c);
  static const IconData con_circuit_7_a = _FlatIconsFlutterArrows(0xf10d);
  static const IconData con_circuit_8_a = _FlatIconsFlutterArrows(0xf10e);
  static const IconData con_circuit_9_a = _FlatIconsFlutterArrows(0xf10f);
  static const IconData con_compress_a = _FlatIconsFlutterArrows(0xf110);
  static const IconData con_curved_a = _FlatIconsFlutterArrows(0xf111);
  static const IconData con_curved_arrow_a = _FlatIconsFlutterArrows(0xf112);
  static const IconData con_curved_arrow_1_a = _FlatIconsFlutterArrows(0xf113);
  static const IconData con_curved_arrow_2_a = _FlatIconsFlutterArrows(0xf114);
  static const IconData con_curved_arrow_3_a = _FlatIconsFlutterArrows(0xf115);
  static const IconData con_curved_arrow_4_a = _FlatIconsFlutterArrows(0xf116);
  static const IconData con_curved_arrow_5_a = _FlatIconsFlutterArrows(0xf117);
  static const IconData con_curved_arrow_6_a = _FlatIconsFlutterArrows(0xf118);
  static const IconData con_curved_arrow_7_a = _FlatIconsFlutterArrows(0xf119);
  static const IconData con_curved_arrow_8_a = _FlatIconsFlutterArrows(0xf11a);
  static const IconData con_cycle_a = _FlatIconsFlutterArrows(0xf11b);
  static const IconData con_diagonal_a = _FlatIconsFlutterArrows(0xf11c);
  static const IconData con_diagonal_1_a = _FlatIconsFlutterArrows(0xf11d);
  static const IconData con_diagonal_2_a = _FlatIconsFlutterArrows(0xf11e);
  static const IconData con_diagonal_3_a = _FlatIconsFlutterArrows(0xf11f);
  static const IconData con_diagonal_4_a = _FlatIconsFlutterArrows(0xf120);
  static const IconData con_diagonal_5_a = _FlatIconsFlutterArrows(0xf121);
  static const IconData con_diagonal_6_a = _FlatIconsFlutterArrows(0xf122);
  static const IconData con_diagonal_7_a = _FlatIconsFlutterArrows(0xf123);
  static const IconData con_diagonal_8_a = _FlatIconsFlutterArrows(0xf124);
  static const IconData con_diagonal_9_a = _FlatIconsFlutterArrows(0xf125);
  static const IconData con_diagonal_arrow_a = _FlatIconsFlutterArrows(0xf126);
  static const IconData con_diagonal_arrow_1_a = _FlatIconsFlutterArrows(0xf127);
  static const IconData con_divide_a = _FlatIconsFlutterArrows(0xf128);
  static const IconData con_down_arrow_a = _FlatIconsFlutterArrows(0xf129);
  static const IconData con_down_arrow_1_a = _FlatIconsFlutterArrows(0xf12a);
  static const IconData con_down_arrow_2_a = _FlatIconsFlutterArrows(0xf12b);
  static const IconData con_down_arrow_3_a = _FlatIconsFlutterArrows(0xf12c);
  static const IconData con_down_arrow_4_a = _FlatIconsFlutterArrows(0xf12d);
  static const IconData con_down_arrow_5_a = _FlatIconsFlutterArrows(0xf12e);
  static const IconData con_download_a = _FlatIconsFlutterArrows(0xf12f);
  static const IconData con_download_1_a = _FlatIconsFlutterArrows(0xf130);
  static const IconData con_download_2_a = _FlatIconsFlutterArrows(0xf131);
  static const IconData con_download_3_a = _FlatIconsFlutterArrows(0xf132);
  static const IconData con_download_4_a = _FlatIconsFlutterArrows(0xf133);
  static const IconData con_download_5_a = _FlatIconsFlutterArrows(0xf134);
  static const IconData con_drag_a = _FlatIconsFlutterArrows(0xf135);
  static const IconData con_drag_1_a = _FlatIconsFlutterArrows(0xf136);
  static const IconData con_drag_10_a = _FlatIconsFlutterArrows(0xf137);
  static const IconData con_drag_11_a = _FlatIconsFlutterArrows(0xf138);
  static const IconData con_drag_2_a = _FlatIconsFlutterArrows(0xf139);
  static const IconData con_drag_3_a = _FlatIconsFlutterArrows(0xf13a);
  static const IconData con_drag_4_a = _FlatIconsFlutterArrows(0xf13b);
  static const IconData con_drag_5_a = _FlatIconsFlutterArrows(0xf13c);
  static const IconData con_drag_6_a = _FlatIconsFlutterArrows(0xf13d);
  static const IconData con_drag_7_a = _FlatIconsFlutterArrows(0xf13e);
  static const IconData con_drag_8_a = _FlatIconsFlutterArrows(0xf13f);
  static const IconData con_drag_9_a = _FlatIconsFlutterArrows(0xf140);
  static const IconData con_expand_a = _FlatIconsFlutterArrows(0xf141);
  static const IconData con_expand_1_a = _FlatIconsFlutterArrows(0xf142);
  static const IconData con_expand_2_a = _FlatIconsFlutterArrows(0xf143);
  static const IconData con_expand_3_a = _FlatIconsFlutterArrows(0xf144);
  static const IconData con_expand_4_a = _FlatIconsFlutterArrows(0xf145);
  static const IconData con_expand_5_a = _FlatIconsFlutterArrows(0xf146);
  static const IconData con_expand_6_a = _FlatIconsFlutterArrows(0xf147);
  static const IconData con_expand_7_a = _FlatIconsFlutterArrows(0xf148);
  static const IconData con_fast_forward_a = _FlatIconsFlutterArrows(0xf149);
  static const IconData con_focus_a = _FlatIconsFlutterArrows(0xf14a);
  static const IconData con_focus_1_a = _FlatIconsFlutterArrows(0xf14b);
  static const IconData con_forward_a = _FlatIconsFlutterArrows(0xf14c);
  static const IconData con_forward_1_a = _FlatIconsFlutterArrows(0xf14d);
  static const IconData con_horizontal_arrows_a = _FlatIconsFlutterArrows(0xf14e);
  static const IconData con_import_a = _FlatIconsFlutterArrows(0xf150);
  static const IconData con_left_arrow_a = _FlatIconsFlutterArrows(0xf151);
  static const IconData con_left_arrow_1_a = _FlatIconsFlutterArrows(0xf152);
  static const IconData con_left_arrow_2_a = _FlatIconsFlutterArrows(0xf153);
  static const IconData con_left_arrow_3_a = _FlatIconsFlutterArrows(0xf154);
  static const IconData con_left_arrow_4_a = _FlatIconsFlutterArrows(0xf155);
  static const IconData con_left_arrow_5_a = _FlatIconsFlutterArrows(0xf156);
  static const IconData con_left_arrow_6_a = _FlatIconsFlutterArrows(0xf157);
  static const IconData con_minimize_a = _FlatIconsFlutterArrows(0xf158);
  static const IconData con_minimize_1_a = _FlatIconsFlutterArrows(0xf159);
  static const IconData con_minimize_2_a = _FlatIconsFlutterArrows(0xf15a);
  static const IconData con_move_a = _FlatIconsFlutterArrows(0xf15b);
  static const IconData con_move_1_a = _FlatIconsFlutterArrows(0xf15c);
  static const IconData con_move_2_a = _FlatIconsFlutterArrows(0xf15d);
  static const IconData con_move_3_a = _FlatIconsFlutterArrows(0xf15e);
  static const IconData con_multiply_a = _FlatIconsFlutterArrows(0xf15f);
  static const IconData con_multiply_1_a = _FlatIconsFlutterArrows(0xf160);
  static const IconData con_multiply_2_a = _FlatIconsFlutterArrows(0xf161);
  static const IconData con_multiply_3_a = _FlatIconsFlutterArrows(0xf162);
  static const IconData con_multiply_4_a = _FlatIconsFlutterArrows(0xf163);
  static const IconData con_multiply_5_a = _FlatIconsFlutterArrows(0xf164);
  static const IconData con_multiply_6_a = _FlatIconsFlutterArrows(0xf165);
  static const IconData con_multiply_7_a = _FlatIconsFlutterArrows(0xf166);
  static const IconData con_multiply_8_a = _FlatIconsFlutterArrows(0xf167);
  static const IconData con_multiply_9_a = _FlatIconsFlutterArrows(0xf168);
  static const IconData con_next_a = _FlatIconsFlutterArrows(0xf169);
  static const IconData con_next_1_a = _FlatIconsFlutterArrows(0xf16a);
  static const IconData con_orbit_a = _FlatIconsFlutterArrows(0xf16b);
  static const IconData con_play_button_a = _FlatIconsFlutterArrows(0xf16c);
  static const IconData con_random_a = _FlatIconsFlutterArrows(0xf16d);
  static const IconData con_refresh_a = _FlatIconsFlutterArrows(0xf16e);
  static const IconData con_repeat_a = _FlatIconsFlutterArrows(0xf16f);
  static const IconData con_repeat_1_a = _FlatIconsFlutterArrows(0xf170);
  static const IconData con_resize_a = _FlatIconsFlutterArrows(0xf171);
  static const IconData con_return_a = _FlatIconsFlutterArrows(0xf172);
  static const IconData con_return_1_a = _FlatIconsFlutterArrows(0xf173);
  static const IconData con_return_2_a = _FlatIconsFlutterArrows(0xf174);
  static const IconData con_return_3_a = _FlatIconsFlutterArrows(0xf175);
  static const IconData con_rewind_a = _FlatIconsFlutterArrows(0xf176);
  static const IconData con_right_a = _FlatIconsFlutterArrows(0xf177);
  static const IconData con_right_arrow_a = _FlatIconsFlutterArrows(0xf178);
  static const IconData con_right_arrow_1_a = _FlatIconsFlutterArrows(0xf179);
  static const IconData con_right_arrow_2_a = _FlatIconsFlutterArrows(0xf17a);
  static const IconData con_right_arrow_3_a = _FlatIconsFlutterArrows(0xf17b);
  static const IconData con_right_arrow_4_a = _FlatIconsFlutterArrows(0xf17c);
  static const IconData con_right_arrow_5_a = _FlatIconsFlutterArrows(0xf17d);
  static const IconData con_right_arrow_6_a = _FlatIconsFlutterArrows(0xf17e);
  static const IconData con_roundabout_a = _FlatIconsFlutterArrows(0xf17f);
  static const IconData con_roundabout_1_a = _FlatIconsFlutterArrows(0xf180);
  static const IconData con_shuffle_a = _FlatIconsFlutterArrows(0xf181);
  static const IconData con_shuffle_1_a = _FlatIconsFlutterArrows(0xf182);
  static const IconData con_shuffle_2_a = _FlatIconsFlutterArrows(0xf183);
  static const IconData con_sort_a = _FlatIconsFlutterArrows(0xf184);
  static const IconData con_sort_1_a = _FlatIconsFlutterArrows(0xf185);
  static const IconData con_spin_a = _FlatIconsFlutterArrows(0xf186);
  static const IconData con_spin_1_a = _FlatIconsFlutterArrows(0xf187);
  static const IconData con_spin_2_a = _FlatIconsFlutterArrows(0xf188);
  static const IconData con_spin_3_a = _FlatIconsFlutterArrows(0xf189);
  static const IconData con_square_a = _FlatIconsFlutterArrows(0xf18a);
  static const IconData con_transfer_a = _FlatIconsFlutterArrows(0xf18b);
  static const IconData con_transfer_1_a = _FlatIconsFlutterArrows(0xf18c);
  static const IconData con_transfer_2_a = _FlatIconsFlutterArrows(0xf18d);
  static const IconData con_transfer_3_a = _FlatIconsFlutterArrows(0xf18e);
  static const IconData con_transfer_4_a = _FlatIconsFlutterArrows(0xf18f);
  static const IconData con_transfer_5_a = _FlatIconsFlutterArrows(0xf190);
  static const IconData con_transfer_6_a = _FlatIconsFlutterArrows(0xf191);
  static const IconData con_transfer_7_a = _FlatIconsFlutterArrows(0xf192);
  static const IconData con_transfer_8_a = _FlatIconsFlutterArrows(0xf193);
  static const IconData con_up_arrow_a = _FlatIconsFlutterArrows(0xf194);
  static const IconData con_up_arrow_1_a = _FlatIconsFlutterArrows(0xf195);
  static const IconData con_up_arrow_2_a = _FlatIconsFlutterArrows(0xf196);
  static const IconData con_up_arrow_3_a = _FlatIconsFlutterArrows(0xf197);
  static const IconData con_up_arrow_4_a = _FlatIconsFlutterArrows(0xf198);
  static const IconData con_up_arrow_5_a = _FlatIconsFlutterArrows(0xf199);
  static const IconData con_up_arrow_6_a = _FlatIconsFlutterArrows(0xf19a);
  static const IconData con_up_arrow_7_a = _FlatIconsFlutterArrows(0xf19b);
  static const IconData con_up_arrow_8_a = _FlatIconsFlutterArrows(0xf19c);
  static const IconData con_upload_a = _FlatIconsFlutterArrows(0xf19d);
  static const IconData con_upload_1_a = _FlatIconsFlutterArrows(0xf19e);
  static const IconData con_upward_a = _FlatIconsFlutterArrows(0xf19f);
}
